﻿/*
  In App.xaml:
  <Application.Resources>
      <vm:SliderSampleViewModelLocator xmlns:vm="clr-namespace:XamSliderBindingSample.ViewModel"
                                   x:Key="Locator" />
  </Application.Resources>
  
  In the View:
  DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"
*/

namespace XamSliderBindingSample.ViewModel
{
    /// <summary>
    /// This class contains static references to all the view models in the
    /// application and provides an entry point for the bindings.
    /// <para>
    /// Use the <strong>mvvmlocatorproperty</strong> snippet to add ViewModels
    /// to this locator.
    /// </para>
    /// <para>
    /// In Silverlight and WPF, place the SliderSampleViewModelLocator in the App.xaml resources:
    /// </para>
    /// <code>
    /// &lt;Application.Resources&gt;
    ///     &lt;vm:SliderSampleViewModelLocator xmlns:vm="clr-namespace:XamSliderBindingSample.ViewModel"
    ///                                  x:Key="Locator" /&gt;
    /// &lt;/Application.Resources&gt;
    /// </code>
    /// <para>
    /// Then use:
    /// </para>
    /// <code>
    /// DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"
    /// </code>
    /// <para>
    /// You can also use Blend to do all this with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm/getstarted
    /// </para>
    /// </summary>
    public class SliderSampleViewModelLocator
    {
        /// <summary>
        /// Initializes a new instance of the SliderSampleViewModelLocator class.
        /// </summary>
        public SliderSampleViewModelLocator()
        {
        }

        private static SliderSampleViewModel _sliderSample;

        /// <summary>
        /// Gets the SliderSample property.
        /// </summary>
        public static SliderSampleViewModel SliderSampleStatic
        {
            get
            {
                if (_sliderSample == null)
                {
                    CreateSliderSample();
                }

                return _sliderSample;
            }
        }

        /// <summary>
        /// Gets the SliderSample property.
        /// </summary>
        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance",
            "CA1822:MarkMembersAsStatic",
            Justification = "This non-static member is needed for data binding purposes.")]
        public SliderSampleViewModel SliderSample
        {
            get
            {
                return SliderSampleStatic;
            }
        }

        /// <summary>
        /// Provides a deterministic way to delete the SliderSample property.
        /// </summary>
        public static void ClearSliderSample()
        {
            _sliderSample.Cleanup();
            _sliderSample = null;
        }

        /// <summary>
        /// Provides a deterministic way to create the SliderSample property.
        /// </summary>
        public static void CreateSliderSample()
        {
            if (_sliderSample == null)
            {
                _sliderSample = new SliderSampleViewModel();
            }
        }

        /// <summary>
        /// Cleans up all the resources.
        /// </summary>
        public static void Cleanup()
        {
            ClearSliderSample();
        }
    }
}